**Main author:** Adrian Price-Whelan (`@adrn <https://github.com/adrn>`_)

All contributors (alphabetical last name):

* Dan Foreman-Mackey
* Nico Garavito-Camargo
* Johnny Greco
* Akeem Hart
* Sergey Koposov
* Daniel Lenz
* Sophia Lilleengen
* Pey Lian Lim
* Syrtis Major
* Semyeong Oh
* Brigitta Sipőcz
* Nathaniel Starkman
* Tom Wagg
